@@ -1,6 +1,6 @@
 package Statistics::R::IO::Base;
 # ABSTRACT: Common object methods for processing R files
-$Statistics::R::IO::Base::VERSION = '0.071';
+$Statistics::R::IO::Base::VERSION = '0.08';
 use 5.012;
 
 use IO::File;
@@ -11,19 +11,14 @@ use IO::Uncompress::Bunzip2 ();
 use Scalar::Util qw(blessed);
 use Carp;
 
-use Moo::Role;
+use Moose::Role;
 
 requires qw( read );
 
 has fh => (
     is => 'ro',
     required => 1,
-    isa => sub {
-        my $obj = shift;
-        die "'fh' must be a file handle"
-            unless (blessed($obj) && $obj->isa('IO::Handle')) ||
-            UNIVERSAL::isa($obj, 'GLOB')
-    }
+    isa => 'FileHandle',
 );
 
 
@@ -111,7 +106,7 @@ Statistics::R::IO::Base - Common object methods for processing R files
 
 =head1 VERSION
 
-version 0.071
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -125,7 +120,7 @@ version 0.071
 =head1 DESCRIPTION
 
 An object of this class represents a handle to an R-related file. This
-class cannot be directly instantiated (it's a L<Moo::Role>), because
+class cannot be directly instantiated (it's a L<Moose::Role>), because
 it is intended as a base abstract class with concrete subclasses to
 parse specific types of files, such as RDS or RData.
 
