@@ -1,9 +1,9 @@
 package Statistics::R::IO::RData;
 # ABSTRACT: Supply object methods for RData files
-$Statistics::R::IO::RData::VERSION = '0.071';
+$Statistics::R::IO::RData::VERSION = '0.08';
 use 5.012;
 
-use Moo;
+use Moose;
 
 with 'Statistics::R::IO::Base';
 
@@ -30,6 +30,8 @@ sub read {
 }
 
     
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -44,7 +46,7 @@ Statistics::R::IO::RData - Supply object methods for RData files
 
 =head1 VERSION
 
-version 0.071
+version 0.08
 
 =head1 SYNOPSIS
 
