@@ -1,31 +1,31 @@
 package Statistics::R::REXP::Raw;
 # ABSTRACT: an R raw vector
-$Statistics::R::REXP::Raw::VERSION = '0.071';
+$Statistics::R::REXP::Raw::VERSION = '0.08';
 use 5.012;
 
 use Scalar::Util qw(looks_like_number);
 
-use Moo;
+use Moose;
 use namespace::clean;
 
 with 'Statistics::R::REXP::Vector';
+use overload;
 
-has '+elements' => (
-    coerce => sub {
-        my $x = shift;
-        [ map { looks_like_number $_ && ($_ >= 0) && ($_ <= 255) ?
-                    int($_) : die "Elements of raw vectors must be 0-255" }
-              _flatten(@{$x}) ] if ref $x eq ref []
-    },
-);
 
 has '+attributes' => (
-    isa => sub { die 'Raw vectors cannot have attributes' if defined shift; },
+    trigger => sub {
+        die 'Raw vectors cannot have attributes'
+    });
+
+has '+elements' => (
+    isa => 'RawElements',
 );
 
-
 sub _type { 'raw'; }
 
+
+__PACKAGE__->meta->make_immutable;
+
 1; # End of Statistics::R::REXP::Raw
 
 __END__
@@ -40,7 +40,7 @@ Statistics::R::REXP::Raw - an R raw vector
 
 =head1 VERSION
 
-version 0.071
+version 0.08
 
 =head1 SYNOPSIS
 
